"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var ts_smart_logger_1 = require("ts-smart-logger");
var util_1 = require("../../../util");
var text_field_1 = require("../text-field");
var menu_1 = require("../../menu");
var definition_1 = require("../../../definition");
var BaseSelect = /** @class */ (function (_super) {
    __extends(BaseSelect, _super);
    /**
     * @stable [30.11.2019]
     * @param {TProps} props
     */
    function BaseSelect(props) {
        var _this = _super.call(this, props) || this;
        _this.menuRef = React.createRef();
        _this.getMenuAnchorElement = _this.getMenuAnchorElement.bind(_this);
        _this.getMenuWidth = _this.getMenuWidth.bind(_this);
        _this.onClose = _this.onClose.bind(_this);
        _this.onDropDownClick = _this.onDropDownClick.bind(_this);
        _this.onFilterChange = _this.onFilterChange.bind(_this);
        _this.onOptionsLoadDone = _this.onOptionsLoadDone.bind(_this);
        _this.onSelect = _this.onSelect.bind(_this);
        _this.openMenu = _this.openMenu.bind(_this);
        if (_this.isExpandActionRendered) {
            _this.defaultActions = [
                { type: _this.systemBaseSelectProps.icon || props.icon || definition_1.FieldActionTypesEnum.DROP_DOWN, onClick: _this.onDropDownClick }
            ].concat(_this.defaultActions);
        }
        if (_this.isQuickSearchEnabled) {
            _this.quickFilterQueryTask = new util_1.DelayedTask(_this.notifyQuickSearchFilterChange.bind(_this), _this.delayTimeout);
        }
        return _this;
    }
    /**
     * @stable [11.01.2020]
     * @param {IBaseEvent} event
     */
    BaseSelect.prototype.onChange = function (event) {
        _super.prototype.onChange.call(this, event);
        this.startQuickSearchIfApplicable();
    };
    /**
     * @stable [29.01.2020]
     * @param {Readonly<TProps extends IBaseSelectProps>} prevProps
     * @param {Readonly<TState extends IBaseSelectState>} prevState
     */
    BaseSelect.prototype.componentDidUpdate = function (prevProps, prevState) {
        _super.prototype.componentDidUpdate.call(this, prevProps, prevState);
        var props = this.props;
        if (this.state.progress
            && !props.waitingForOptions && prevProps.waitingForOptions) {
            // We can't use progress props because it is reserved
            // The new data have come
            this.setState({ progress: false }, this.onOptionsLoadDone);
        }
        this.tryResetCachedValue(props, prevProps);
    };
    /**
     * @stable [31.01.2020]
     */
    BaseSelect.prototype.componentWillUnmount = function () {
        _super.prototype.componentWillUnmount.call(this);
        this.cancelQueryFilterTask();
    };
    /**
     * @stable [11.01.2020]
     * @param {IBaseEvent} event
     */
    BaseSelect.prototype.onKeyEscape = function (event) {
        _super.prototype.onKeyEscape.call(this, event);
        this.hideMenu();
    };
    /**
     * @stable [30.01.2020]
     */
    BaseSelect.prototype.clearValue = function () {
        _super.prototype.clearValue.call(this);
        if (this.isPlainValueApplied) {
            this.clearCachedValue();
        }
    };
    /**
     * @stable [11.01.2020]
     */
    BaseSelect.prototype.openMenu = function () {
        var _this = this;
        if (this.isFieldBusy() || this.isMenuAlreadyRenderedAndOpened) {
            return;
        }
        var $isForceReload = this.isForceReload;
        var $doOptionsExist = this.doOptionsExist;
        BaseSelect.logger.debug('[$BaseSelect][openMenu] isForceReload:', $isForceReload, ', doOptionsExist:', $doOptionsExist);
        if ($isForceReload || !$doOptionsExist) {
            var onEmptyDictionary_1 = this.props.onEmptyDictionary;
            if (util_1.isFn(onEmptyDictionary_1)) {
                BaseSelect.logger.debug('[$BaseSelect][openMenu] The onEmptyDictionary callback is defined, need to load options...');
                this.setState({ progress: true }, function () { return onEmptyDictionary_1(_this.dictionary); });
            }
            else {
                BaseSelect.logger.debug('[$BaseSelect][openMenu] The onEmptyDictionary callback is not defined, menu show needed...');
                // Try open empty dialog menu to remote search
                this.renderAndShowMenu(!this.isQuickSearchEnabled);
            }
        }
        else {
            this.renderAndShowMenu();
        }
    };
    /**
     * @stable [16.01.2020]
     * @param {IBaseEvent} event
     */
    BaseSelect.prototype.onKeyEnter = function (event) {
        if (this.startQuickSearchIfApplicable(true)) {
            this.domAccessor.cancelEvent(event);
        }
        _super.prototype.onKeyEnter.call(this, event);
    };
    /**
     * @stable [28.01.2020]
     * @param {IBaseEvent} event
     */
    BaseSelect.prototype.onClick = function (event) {
        _super.prototype.onClick.call(this, event);
        var isQuickSearchEnabled = this.isQuickSearchEnabled;
        var isLocalOptionsUsed = this.isLocalOptionsUsed;
        BaseSelect.logger.debug('[$BaseSelect][onClick] isQuickSearchEnabled:', isQuickSearchEnabled, ', isLocalOptionsUsed:', isLocalOptionsUsed);
        if (isQuickSearchEnabled && !isLocalOptionsUsed) {
            if (this.isFieldBusy()) {
                BaseSelect.logger.debug('[$BaseSelect][onClick] The field is busy. Do nothing...');
            }
            else {
                this.notifyQuickSearchFilterChange();
            }
        }
        else {
            this.openMenu();
        }
    };
    Object.defineProperty(BaseSelect.prototype, "inputAttachmentElement", {
        /**
         * @stable [22.01.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            var _this = this;
            return util_1.orNull(this.isMenuRendered, // To improve a performance
            function () { return (React.createElement(menu_1.Menu, __assign({ ref: _this.menuRef, anchorElement: util_1.orNull(_this.isMenuAnchored, function () { return _this.getMenuAnchorElement; }), width: util_1.orNull(_this.isMenuAnchored, function () { return _this.getMenuWidth; }), progress: _this.isFieldBusy(), options: _this.getFilteredOptions(), onSelect: _this.onSelect, onFilterChange: _this.onFilterChange, onClose: _this.onClose }, _this.getMenuProps()))); });
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [09.01.2020]
     * @returns {IMenuProps}
     */
    BaseSelect.prototype.getMenuProps = function () {
        return this.props.menuConfiguration;
    };
    /**
     * @stable [31.01.2020]
     * @param {(option: ISelectOptionEntity) => boolean} filter
     * @returns {ISelectOptionEntity[]}
     */
    BaseSelect.prototype.getFilteredOptions = function (filter) {
        var _this = this;
        var value = this.value;
        var doesFilterExist = util_1.isFn(filter);
        if (this.isQuickSearchEnabled
            && (this.isForceUseLocalFilter || this.isLocalOptionsUsed)
            && !this.isValueObject(value)
            && util_1.isObjectNotEmpty(value)) {
            var originalFilter_1 = function (option) { return util_1.queryFilter(value, _this.selectOptionEntityAsDisplayValue(option)); };
            return this.options.filter(doesFilterExist
                ? function (option) { return originalFilter_1(option) && filter(option); }
                : originalFilter_1);
        }
        return doesFilterExist
            ? this.options.filter(filter)
            : this.options;
    };
    /**
     * @stable [28.01.2020]
     * @returns {boolean}
     */
    BaseSelect.prototype.isFieldBusy = function () {
        return util_1.inProgress(this.state);
    };
    /**
     * @stable [11.01.2020]
     * @returns {string}
     */
    BaseSelect.prototype.getFieldClassName = function () {
        return util_1.joinClassName(_super.prototype.getFieldClassName.call(this), 'rac-base-select');
    };
    Object.defineProperty(BaseSelect.prototype, "originalEmptyValue", {
        /**
         * @stable [21.12.2019]
         * @returns {AnyT}
         */
        get: function () {
            return definition_1.FIELD_VALUE_TO_RESET;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [28.01.2020]
     * @param {ISelectOptionEntity} option
     */
    BaseSelect.prototype.onSelect = function (option) {
        var _this = this;
        if (this.isPlainValueApplied) {
            this.saveCachedValue(util_1.shallowClone(option), function () { return _this.doSelectOption(option); });
        }
        else {
            this.doSelectOption(option);
        }
    };
    /**
     * @stable [11.01.2020]
     * @param {ISelectOptionEntity} option
     */
    BaseSelect.prototype.notifySelectOption = function (option) {
        var onSelect = this.props.onSelect;
        if (!util_1.isDef(option) || !util_1.isFn(onSelect)) {
            return;
        }
        onSelect(option);
    };
    /**
     * @stable [10.09.2019]
     */
    BaseSelect.prototype.onClose = function () {
        var props = this.props;
        if (util_1.isFn(props.onClose)) {
            props.onClose();
        }
    };
    /**
     * @stable [28.01.2020]
     * @param {AnyT} value
     * @returns {AnyT}
     */
    BaseSelect.prototype.getDecoratedDisplayValue = function (value) {
        var _this = this;
        var $$cachedValue = this.$$cashedValue;
        var hasCachedValue = !R.isNil($$cachedValue);
        if (!hasCachedValue && (!this.isQuickSearchEnabled || this.isValueObject(value))) {
            var optionValue_1 = this.selectOptionEntityAsId(value);
            value = util_1.nvl(R.find(function (option) { return _this.selectOptionEntityAsId(option) === optionValue_1; }, this.options), value);
        }
        return _super.prototype.getDecoratedDisplayValue.call(this, hasCachedValue ? $$cachedValue : value, hasCachedValue);
    };
    /**
     * @stable [28.01.2020]
     * @param {AnyT} value
     * @returns {AnyT}
     */
    BaseSelect.prototype.decorateDisplayValue = function (value) {
        return this.selectOptionEntityAsDisplayValue(value);
    };
    Object.defineProperty(BaseSelect.prototype, "options", {
        /**
         * @stable [11.01.2020]
         * @returns {ISelectOptionEntity[]}
         */
        get: function () {
            return util_1.nvl(this.props.options, []);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseSelect.prototype, "isExpandActionRendered", {
        /**
         * @stable [11.01.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isExpandActionRendered(this.props);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseSelect.prototype, "isAllowEmptyFilterValue", {
        /**
         * @stable [28.01.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isAllowEmptyFilterValue(this.props);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [28.01.2020]
     * @returns {EntityIdT}
     */
    BaseSelect.prototype.selectOptionEntityAsId = function (value) {
        return this.fieldConverter.convert({
            value: value,
            from: definition_1.FieldConverterTypesEnum.SELECT_OPTION_ENTITY,
            to: definition_1.FieldConverterTypesEnum.ID,
        });
    };
    /**
     * @stable [28.01.2020]
     */
    BaseSelect.prototype.notifyQuickSearchFilterChange = function () {
        var _this = this;
        if (this.isValueObject(this.value)) {
            // Why we should search the same value object instance?
            BaseSelect.logger.debug('[$BaseSelect][notifyQuickSearchFilterChange] The value is an object. Do nothing...');
            return;
        }
        var currentValue = this.decoratedDisplayValue;
        var isCurrentValueNotEmpty = util_1.isObjectNotEmpty(currentValue);
        var isAllowEmptyFilterValue0 = this.isAllowEmptyFilterValue;
        if (!isAllowEmptyFilterValue0 && !isCurrentValueNotEmpty) {
            BaseSelect.logger.debug('[$BaseSelect][notifyQuickSearchFilterChange] The decorated value is empty. Do nothing...');
            return;
        }
        this.setState({ progress: true }, function () {
            BaseSelect.logger.debug('[$BaseSelect][notifyQuickSearchFilterChange] The onFilterChange method is being call. The current value:', currentValue);
            _this.onFilterChange(currentValue);
        });
    };
    /**
     * @stable [11.01.2020]
     * @param {IBaseEvent} event
     */
    BaseSelect.prototype.onDropDownClick = function (event) {
        this.domAccessor.cancelEvent(event);
        this.openMenu();
        this.setFocus();
    };
    /**
     * @stable [28.01.2020]
     * @param {ISelectOptionEntity} option
     */
    BaseSelect.prototype.doSelectOption = function (option) {
        this.onChangeManually(this.isPlainValueApplied ? this.selectOptionEntityAsId(option) : option);
        this.notifySelectOption(option);
        this.setFocus();
    };
    /**
     * @stable [01.02.2020]
     * @param {string} query
     */
    BaseSelect.prototype.onFilterChange = function (query) {
        var props = this.props;
        var onFilterChange = props.onFilterChange;
        var onDictionaryFilterChange = props.onDictionaryFilterChange;
        var dictionary = this.dictionary;
        BaseSelect.logger.debug(function (logger) {
            logger.write('[$BaseSelect][onFilterChange] onFilterChange:', util_1.isFn(onFilterChange) || '[-]', ', onDictionaryFilterChange:', util_1.isFn(onDictionaryFilterChange) || '[-]', ', dictionary:', dictionary);
        });
        if (util_1.isFn(onFilterChange)) {
            onFilterChange(query);
        }
        if (util_1.isFn(onDictionaryFilterChange)) {
            onDictionaryFilterChange(dictionary, { payload: { query: query } });
        }
    };
    /**
     * @stable [11.01.2020]
     */
    BaseSelect.prototype.hideMenu = function () {
        if (this.isMenuAlreadyRenderedAndOpened) {
            this.setState({ menuRendered: false });
        }
    };
    /**
     * @stable [12.01.2020]
     * @param {boolean} force
     */
    BaseSelect.prototype.renderAndShowMenu = function (force) {
        var _this = this;
        if (force === void 0) { force = false; }
        if (force || !R.isEmpty(this.getFilteredOptions())) {
            this.setState({ menuRendered: true }, function () { return _this.menu.show(); });
        }
        else {
            BaseSelect.logger.debug('[$BaseSelect][renderAndShowMenu] The options are empty. The menu does not show.');
        }
    };
    /**
     * @stable [16.01.2020]
     */
    BaseSelect.prototype.startQuickSearchIfApplicable = function (noDelay) {
        var _this = this;
        if (noDelay === void 0) { noDelay = false; }
        var isQuickSearchEnabled = this.isQuickSearchEnabled;
        var isFieldBusy = this.isFieldBusy();
        var isLocalOptionsUsed = this.isLocalOptionsUsed;
        if (!isQuickSearchEnabled || isFieldBusy || isLocalOptionsUsed) {
            BaseSelect.logger.debug('[$BaseSelect][startQuickSearchIfApplicable] Can\'t start a search because of isQuickSearchEnabled:', isQuickSearchEnabled, ', isFieldBusy:', isFieldBusy, ', isLocalOptionsUsed:', isLocalOptionsUsed);
            if (!this.isMenuAlreadyRenderedAndOpened
                && isQuickSearchEnabled
                && isLocalOptionsUsed) {
                this.renderAndShowMenu(true);
            }
            return false;
        }
        if (this.isPlainValueApplied) {
            this.clearCachedValue(function () { return _this.hideMenuAndStartQuickSearch(noDelay); });
        }
        else {
            this.hideMenuAndStartQuickSearch(noDelay);
        }
        return true;
    };
    /**
     * @stable [28.01.2020]
     */
    BaseSelect.prototype.onOptionsLoadDone = function () {
        this.renderAndShowMenu();
        var props = this.props;
        if (util_1.isFn(props.onLoadDictionary)) {
            props.onLoadDictionary(this.getFilteredOptions());
        }
    };
    /**
     * @stable [30.01.2020]
     * @param {boolean} noDelay
     */
    BaseSelect.prototype.hideMenuAndStartQuickSearch = function (noDelay) {
        if (noDelay === void 0) { noDelay = false; }
        this.hideMenu();
        if (noDelay) {
            this.cancelQueryFilterTask();
            this.notifyQuickSearchFilterChange();
        }
        else {
            this.quickFilterQueryTask.start();
        }
    };
    /**
     * @stable [29.01.2020]
     * @param {TProps} props
     * @param {TProps} previousProps
     */
    BaseSelect.prototype.tryResetCachedValue = function (props, previousProps) {
        if (!this.isPlainValueApplied) {
            return;
        }
        var newValue = props.value;
        if (!R.equals(newValue, previousProps.value)) {
            // The value has changed
            // TODO Pass cached value inside a constructor
            var $$cachedValue = this.$$cashedValue;
            if (!R.isNil($$cachedValue) && !R.equals($$cachedValue.value, newValue)) {
                // Need to reset the previous cached display value if the value has been cleared or replaced
                this.clearCachedValue();
            }
        }
    };
    /**
     * @stable [31.01.2020]
     */
    BaseSelect.prototype.cancelQueryFilterTask = function () {
        util_1.ifNotNilThanValue(this.quickFilterQueryTask, function (task) { return task.stop(); });
    };
    /**
     * @stable [30.01.2020]
     * @param {() => void} callback
     */
    BaseSelect.prototype.clearCachedValue = function (callback) {
        this.saveCachedValue(null, callback);
    };
    /**
     * @stable [30.01.2020]
     * @param {ISelectOptionEntity} value
     * @param {() => void} callback
     */
    BaseSelect.prototype.saveCachedValue = function (value, callback) {
        this.setState({ $$cachedValue: value }, callback);
    };
    /**
     * @stable [31.01.2020]
     * @param {ISelectOptionEntity | StringNumberT} value
     * @returns {StringNumberT}
     */
    BaseSelect.prototype.selectOptionEntityAsDisplayValue = function (value) {
        return this.fieldConverter.convert({
            value: value,
            from: definition_1.FieldConverterTypesEnum.SELECT_OPTION_ENTITY,
            to: definition_1.FieldConverterTypesEnum.DISPLAY_VALUE,
        });
    };
    Object.defineProperty(BaseSelect.prototype, "isQuickSearchEnabled", {
        /**
         * @stable [29.01.2020]
         * @returns {boolean}
         */
        get: function () {
            return !this.isFocusPrevented;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [24.01.2020]
     * @returns {number}
     */
    BaseSelect.prototype.getMenuWidth = function () {
        return this.domAccessor.getWidth(this.getSelf());
    };
    Object.defineProperty(BaseSelect.prototype, "delayTimeout", {
        /**
         * @stable [11.01.2020]
         * @returns {number}
         */
        get: function () {
            return util_1.nvl(this.props.delayTimeout, 1000);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseSelect.prototype, "doOptionsExist", {
        /**
         * @stable [15.01.2020]
         * @returns {boolean}
         */
        get: function () {
            return !R.isNil(this.props.options);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseSelect.prototype, "isMenuRendered", {
        /**
         * @stable [22.01.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isMenuRendered(this.state);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseSelect.prototype, "isLocalOptionsUsed", {
        /**
         * @stable [28.01.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isUndef(this.props.waitingForOptions);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseSelect.prototype, "isMenuAnchored", {
        /**
         * @stable [24.01.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isAnchored(this.props);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseSelect.prototype, "isForceUseLocalFilter", {
        /**
         * @stable [01.02.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isForceUseLocalFilter(this.props);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseSelect.prototype, "isForceReload", {
        /**
         * @stable [31.01.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isForceReload(this.props);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseSelect.prototype, "isMenuAlreadyRenderedAndOpened", {
        /**
         * @stable [11.01.2020]
         * @returns {boolean}
         */
        get: function () {
            var menu = this.menu;
            return !R.isNil(menu) && menu.isOpen();
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [24.01.2020]
     * @returns {HTMLElement}
     */
    BaseSelect.prototype.getMenuAnchorElement = function () {
        return util_1.calc(this.props.menuAnchorElement) || this.input;
    };
    Object.defineProperty(BaseSelect.prototype, "menu", {
        /**
         * @stable [30.11.2019]
         * @returns {IMenu}
         */
        get: function () {
            return this.menuRef.current;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseSelect.prototype, "$$cashedValue", {
        /**
         * @stable [30.01.2020]
         * @returns {ISelectOptionEntity}
         */
        get: function () {
            return this.state.$$cachedValue;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseSelect.prototype, "dictionary", {
        /**
         * @stable [01.02.2020]
         * @returns {string}
         */
        get: function () {
            var _a = this.props, dictionary = _a.dictionary, bindDictionary = _a.bindDictionary;
            return util_1.nvl(dictionary, bindDictionary); // bindDictionary is used by Form
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseSelect.prototype, "systemBaseSelectProps", {
        /**
         * @stable [17.02.2020]
         * @returns {TProps}
         */
        get: function () {
            var _a = (this.settings.components || {}).baseSelect, baseSelect = _a === void 0 ? {} : _a;
            return baseSelect;
        },
        enumerable: true,
        configurable: true
    });
    BaseSelect.logger = ts_smart_logger_1.LoggerFactory.makeLogger('BaseSelect');
    return BaseSelect;
}(text_field_1.BaseTextField));
exports.BaseSelect = BaseSelect;
//# sourceMappingURL=base-select.component.js.map