"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var redux_effects_promise_1 = require("redux-effects-promise");
var util_1 = require("../../util");
var definitions_interface_1 = require("../../definitions.interface");
var form_interface_1 = require("./form.interface");
var FormActionBuilder = /** @class */ (function () {
    function FormActionBuilder() {
    }
    /**
     * @stable [21.01.2019]
     * @param {string} section
     * @returns {string}
     */
    FormActionBuilder.buildDestroyActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + form_interface_1.FORM_DESTROY_ACTION_TYPE;
    };
    /**
     * @stable [26.08.2018]
     * @param {string} section
     * @returns {string}
     */
    FormActionBuilder.buildClearActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + form_interface_1.FORM_CLEAR_ACTION_TYPE;
    };
    /**
     * @stable [02.10.2018]
     * @param {string} section
     * @returns {string}
     */
    FormActionBuilder.buildChangeActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + form_interface_1.FORM_CHANGE_ACTION_TYPE;
    };
    /**
     * @stable [20.12.2019]
     * @param {string} section
     * @returns {string}
     */
    FormActionBuilder.buildDefaultChangeActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + form_interface_1.FORM_DEFAULT_CHANGE_ACTION_TYPE;
    };
    /**
     * @stable [24.02.2019]
     * @param {string} section
     * @returns {string}
     */
    FormActionBuilder.buildResetActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + form_interface_1.FORM_RESET_ACTION_TYPE;
    };
    /**
     * @stable [03.04.2019]
     * @param {string} section
     * @returns {string}
     */
    FormActionBuilder.buildValidActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + form_interface_1.FORM_VALID_ACTION_TYPE;
    };
    /**
     * @stable [14.08.2018]
     * @param {string} section
     * @returns {string}
     */
    FormActionBuilder.buildActiveValueActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + form_interface_1.FORM_ACTIVE_VALUE_ACTION_TYPE;
    };
    /**
     * @stable [02.09.2018]
     * @param {string} section
     * @returns {string}
     */
    FormActionBuilder.buildDeactivatedValueActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + form_interface_1.FORM_DEACTIVATED_VALUE_ACTION_TYPE;
    };
    /**
     * @stable [02.04.2019]
     * @param {string} section
     * @returns {string}
     */
    FormActionBuilder.buildSubmitActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + form_interface_1.FORM_SUBMIT_ACTION_TYPE;
    };
    /**
     * @stable [17.04.2019]
     * @param {string} section
     * @returns {string}
     */
    FormActionBuilder.buildProgressActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + form_interface_1.FORM_PROGRESS_ACTION_TYPE;
    };
    /**
     * @stable [02.04.2019]
     * @param {string} section
     * @returns {string}
     */
    FormActionBuilder.buildSubmitDoneActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + form_interface_1.FORM_SUBMIT_DONE_ACTION_TYPE;
    };
    /**
     * @stable [03.04.2019]
     * @param {string} section
     * @returns {string}
     */
    FormActionBuilder.buildSubmitFinishedActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + form_interface_1.FORM_SUBMIT_FINISHED_ACTION_TYPE;
    };
    /**
     * @stable [03.04.2019]
     * @param {string} section
     * @returns {string}
     */
    FormActionBuilder.buildSubmitErrorActionType = function (section) {
        return util_1.toActionPrefix(section) + "." + form_interface_1.FORM_SUBMIT_ERROR_ACTION_TYPE;
    };
    /**
     * @stable [02.04.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    FormActionBuilder.buildSubmitDoneAction = function (section) {
        return redux_effects_promise_1.EffectsAction.create(this.buildSubmitDoneActionType(section), util_1.applySection(section));
    };
    /**
     * @stable [24.02.2019]
     * @param {string} section
     * @returns {string}
     */
    FormActionBuilder.buildResetAction = function (section) {
        return redux_effects_promise_1.EffectsAction.create(this.buildResetActionType(section), util_1.applySection(section));
    };
    /**
     * @stable [17.04.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    FormActionBuilder.buildProgressAction = function (section) {
        return redux_effects_promise_1.EffectsAction.create(this.buildProgressActionType(section), util_1.applySection(section));
    };
    /**
     * @stable [03.02.2020]
     * @param {string} section
     * @param {boolean} valid
     * @returns {IEffectsAction}
     */
    FormActionBuilder.buildValidAction = function (section, valid) {
        var plainAction = this.buildValidPlainAction(section, valid);
        return redux_effects_promise_1.EffectsAction.create(plainAction.type, plainAction.data);
    };
    FormActionBuilder.buildSubmitFinishedAction = function (section) {
        return redux_effects_promise_1.EffectsAction.create(this.buildSubmitFinishedActionType(section), util_1.applySection(section));
    };
    /**
     * @stable [21.01.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    FormActionBuilder.buildDestroyAction = function (section) {
        return redux_effects_promise_1.EffectsAction.create(this.buildDestroyActionType(section), util_1.applySection(section));
    };
    /**
     * @stable [03.02.2020]
     * @param {string} section
     * @param {string} fieldName
     * @returns {IEffectsAction}
     */
    FormActionBuilder.buildClearPlainAction = function (section, fieldName) {
        var _a;
        return {
            type: this.buildClearActionType(section),
            data: util_1.applySection(section, this.buildChangesPayload((_a = {}, _a[fieldName] = definitions_interface_1.UNDEF, _a))),
        };
    };
    /**
     * @stable [03.02.2020]
     * @param {string} section
     * @param {string} fieldName
     * @returns {IEffectsAction}
     */
    FormActionBuilder.buildClearAction = function (section, fieldName) {
        var plainAction = this.buildClearPlainAction(section, fieldName);
        return redux_effects_promise_1.EffectsAction.create(plainAction.type, plainAction.data);
    };
    /**
     * @stable [03.02.2020]
     * @param {string} section
     * @param {TData} changes
     * @returns {IEffectsAction}
     */
    FormActionBuilder.buildChangesAction = function (section, changes) {
        var plainAction = this.buildChangesPlainAction(section, changes);
        return redux_effects_promise_1.EffectsAction.create(plainAction.type, plainAction.data);
    };
    FormActionBuilder.buildDefaultChangesAction = function (section, changes) {
        return redux_effects_promise_1.EffectsAction.create(this.buildDefaultChangeActionType(section), util_1.applySection(section, this.buildChangesPayload(changes)));
    };
    /**
     * @stable [03.02.2020]
     * @param {string} section
     * @param {TData} changes
     * @returns {IEffectsAction}
     */
    FormActionBuilder.buildChangesPlainAction = function (section, changes) {
        return {
            type: this.buildChangeActionType(section),
            data: util_1.applySection(section, this.buildChangesPayload(changes)),
        };
    };
    /**
     * @stable [03.02.2020]
     * @param {string} section
     * @param {FieldChangeEntityT} payload
     * @returns {IEffectsAction}
     */
    FormActionBuilder.buildChangePlainAction = function (section, payload) {
        return { type: this.buildChangeActionType(section), data: util_1.applySection(section, payload) };
    };
    /**
     * @stable [11.09.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    FormActionBuilder.buildResetPlainAction = function (section) {
        return { type: this.buildResetActionType(section), data: util_1.applySection(section) };
    };
    /**
     * @stable [01.03.2020]
     * @param {string} section
     * @param {IApiEntity} apiEntity
     * @returns {IEffectsAction}
     */
    FormActionBuilder.buildSubmitPlainAction = function (section, apiEntity) {
        return { type: this.buildSubmitActionType(section), data: util_1.applySection(section, apiEntity) };
    };
    /***
     * @stable [03.02.2020]
     * @param {string} section
     * @param {boolean} valid
     * @returns {IEffectsAction}
     */
    FormActionBuilder.buildValidPlainAction = function (section, valid) {
        var payload = { valid: valid };
        return { type: this.buildValidActionType(section), data: util_1.applySection(section, payload) };
    };
    /**
     * @stable [03.02.2020]
     * @param {IKeyValue} changes
     * @returns {FieldChangeEntityT}
     */
    FormActionBuilder.buildChangesPayload = function (changes) {
        return {
            fields: Object
                .keys(changes)
                .map(function (name) { return ({ name: name, value: Reflect.get(changes, name) }); }),
        };
    };
    return FormActionBuilder;
}());
exports.FormActionBuilder = FormActionBuilder;
//# sourceMappingURL=form-action.builder.js.map