"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var util_1 = require("../../../util");
var di_1 = require("../../../di");
var BaseStoreProxy = /** @class */ (function () {
    /**
     * @stable [09.10.2019]
     * @param {IUniversalContainer<TProps extends IUniversalContainerProps>} container
     */
    function BaseStoreProxy(container) {
        this.container = container;
    }
    /**
     * @stable [03.10.2019]
     * @param {string} type
     * @param {TChanges} data
     */
    BaseStoreProxy.prototype.dispatch = function (type, data) {
        this.dispatchCustomType(this.sectionName + "." + type, util_1.applySection(this.sectionName, data));
    };
    /**
     * @stable [11.09.2019]
     * @param {string} type
     * @param {TData} data
     */
    BaseStoreProxy.prototype.dispatchCustomType = function (type, data) {
        this.dispatchAnyAction({ type: type, data: data });
    };
    /**
     * @stable [11.09.2019]
     * @param {AnyAction} action
     */
    BaseStoreProxy.prototype.dispatchAnyAction = function (action) {
        this.appStore.dispatch(action);
    };
    Object.defineProperty(BaseStoreProxy.prototype, "appStore", {
        /**
         * @reactNativeCompatible
         * @stable [11.09.2019]
         * @returns {Store<TStore>}
         */
        get: function () {
            return di_1.getStore();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseStoreProxy.prototype, "sectionName", {
        /**
         * @stable [11.09.2019]
         * @returns {string}
         */
        get: function () {
            return this.props.sectionName;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseStoreProxy.prototype, "props", {
        /**
         * @stable [11.09.2019]
         * @returns {TProps}
         */
        get: function () {
            return this.container.props;
        },
        enumerable: true,
        configurable: true
    });
    return BaseStoreProxy;
}());
exports.BaseStoreProxy = BaseStoreProxy;
//# sourceMappingURL=base-store.proxy.js.map