"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var env_1 = require("../../../env");
var viewer_component_1 = require("../viewer.component");
var universal_pdf_plugin_1 = require("./universal-pdf.plugin");
var flex_1 = require("../../layout/flex");
var button_1 = require("../../button");
var PdfViewer = /** @class */ (function (_super) {
    __extends(PdfViewer, _super);
    /**
     * @stable [08.07.2018]
     * @param {IPdfViewerProps} props
     */
    function PdfViewer(props) {
        var _this = _super.call(this, props) || this;
        _this.state = { previewPage: 1 };
        _this.onPreviousPage = _this.onPreviousPage.bind(_this);
        _this.onNextPage = _this.onNextPage.bind(_this);
        _this.pdfRendererPlugin = new universal_pdf_plugin_1.UniversalPdfPlugin(_this.settings.pdfWorkerDirectoryUrl + "pdf.worker.min.js?_dc=" + env_1.ENV.appVersion, function () { return _this.refs.canvas; }, function () { return _this.setState({ error: null }); }, function (error) { return _this.setState({ error: error }); });
        return _this;
    }
    /**
     * @stable [14.11.2018]
     * @param {IPdfViewerProps} props
     * @param {IPdfViewerState} state
     */
    PdfViewer.prototype.componentDidUpdate = function (props, state) {
        _super.prototype.componentDidUpdate.call(this, props, state);
        var currentPage = this.props.page;
        if (!R.equals(currentPage, props.page)) {
            this.pdfRendererPlugin
                .setPage(currentPage)
                .refreshPage();
        }
    };
    /**
     * @stable [14.11.2018]
     */
    PdfViewer.prototype.componentWillUnmount = function () {
        this.pdfRendererPlugin.cancel();
        this.pdfRendererPlugin = null;
        _super.prototype.componentWillUnmount.call(this);
    };
    /**
     * @stable [14.11.2018]
     */
    PdfViewer.prototype.refresh = function () {
        var props = this.props;
        var src = props.src;
        if (R.isNil(src)) {
            // This plugin can't process the null value
            return;
        }
        this.pdfRendererPlugin
            .setSrc(src)
            .setScale(props.scale)
            .loadDocument();
    };
    /**
     * @stable [08.07.2018]
     * @returns {JSX.Element}
     */
    PdfViewer.prototype.getContentElement = function () {
        return React.createElement("canvas", { ref: 'canvas' });
    };
    /**
     * @stable [08.07.2018]
     * @returns {JSX.Element}
     */
    PdfViewer.prototype.gePreviewElement = function () {
        var props = this.props;
        var previewScale = props.previewScale;
        var previewWidth = PdfViewer.PREVIEW_WIDTH * previewScale;
        return (React.createElement(React.Fragment, null,
            React.createElement(PdfViewer, { usePreview: false, src: props.src, page: this.state.previewPage, style: { width: '100%' }, scale: previewScale }),
            React.createElement(flex_1.FlexLayout, { full: false, row: true, className: 'pos-neighbor-left-half-offset-wrapper' },
                React.createElement(button_1.Button, { icon: 'back', text: 'Previous page', disabled: this.state.previewPage === 1, onClick: this.onPreviousPage }),
                React.createElement(button_1.Button, { icon: 'forward', text: 'Next page', disabled: this.state.previewPage === this.pdfRendererPlugin.numPages, onClick: this.onNextPage }))));
    };
    Object.defineProperty(PdfViewer.prototype, "isProgressMessageShown", {
        /**
         * @stable [08.07.2018]
         * @returns {boolean}
         */
        get: function () {
            return !this.pdfRendererPlugin.hasLoadedDocument;
        },
        enumerable: true,
        configurable: true
    });
    PdfViewer.prototype.onDialogClose = function () {
        this.setState({ opened: false, previewPage: 1 });
    };
    PdfViewer.prototype.onPreviousPage = function () {
        this.setState({ previewPage: this.state.previewPage - 1 });
    };
    PdfViewer.prototype.onNextPage = function () {
        this.setState({ previewPage: this.state.previewPage + 1 });
    };
    PdfViewer.defaultProps = {
        previewScale: 1.5,
        scale: .3,
        page: 1,
        usePreview: true,
    };
    PdfViewer.PREVIEW_WIDTH = 600;
    return PdfViewer;
}(viewer_component_1.Viewer));
exports.PdfViewer = PdfViewer;
//# sourceMappingURL=pdf-viewer.component.js.map