"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var filter_1 = require("./filter");
var definition_1 = require("../definition");
var definitions_interface_1 = require("../definitions.interface");
var cond_1 = require("./cond");
var type_1 = require("./type");
var entity_1 = require("./entity");
var nvl_1 = require("./nvl");
var wrapper_1 = require("./wrapper");
var select_1 = require("./select");
/**
 * @stable [25.11.2019]
 * @param {IQueueWrapper<TValue>} entity
 * @returns {TValue}
 */
exports.selectQueue = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.queue; }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [17.11.2019]
 * @param {ITransportWrapperEntity} entity
 * @returns {string}
 */
exports.selectTransportWrapperToken = function (entity) {
    return select_1.selectToken(exports.selectTransport(entity));
};
/**
 * @stable [25.11.2019]
 * @param {ITransportWrapperEntity} entity
 * @returns {string[]}
 */
exports.selectTransportWrapperQueue = function (entity) {
    return exports.selectQueue(exports.selectTransport(entity));
};
/**
 * @stable [17.11.2019]
 * @param {ITransportWrapperEntity} entity
 * @returns {ITransportEntity}
 */
exports.selectTransport = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.transport; }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [03.02.2020]
 * @param {IEntityIdTWrapper} entity
 * @returns {EntityIdT}
 */
exports.selectEntityId = function (entity) { return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.id; };
/**
 * @stable [13.02.2020]
 * @param {TErrorWrapper} entity
 * @returns {TResult}
 */
exports.selectError = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.error;
};
/**
 * @stable [29.02.2020]
 * @param {IFormExtendedEditableEntity<TEntity extends IEntity>} wrapper
 * @returns {IEditableEntity<TEntity extends IEntity>}
 */
exports.selectEditableEntity = function (wrapper) {
    return select_1.selectForm(wrapper);
};
/**
 * @stable [20.12.2019]
 * @param {IEditableEntity} entity
 * @returns {TResult}
 */
exports.selectDefaultChanges = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.defaultChanges; }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [21.02.2020]
 * @param {IFormExtendedEditableEntity<TEntity extends IEntity>} entity
 * @returns {TEntity}
 */
exports.selectEditableEntityChanges = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : select_1.selectChanges(exports.selectEditableEntity(entity));
};
/**
 * @stable [19.10.2019]
 * @param {IListWrapperEntity<TEntity extends IEntity>} entity
 * @returns {IListEntity<TEntity extends IEntity>}
 */
exports.selectListEntity = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.list; }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [18.10.2019]
 * @param {IListEntity} entity
 * @returns {ISortDirectionsEntity}
 */
exports.selectListEntityDirections = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.directions; }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [28.09.2019]
 * @param {IUserWrapperEntity} entity
 * @returns {IUserEntity}
 */
exports.selectUserEntity = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.user; }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [29.02.2020]
 * @param {IFilterWrapper<TEntity>} entity
 * @returns {TEntity}
 */
exports.selectFilter = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.filter;
};
/**
 * @stable [19.10.2019]
 * @param {IQueryWrapper} entity
 * @returns {string}
 */
exports.selectQuery = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return nvl_1.trimmedUndefEmpty(entity.query); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [27.11.2019]
 * @param {IQueryFilterWrapperEntity} entity
 * @returns {string}
 */
exports.selectFilterQuery = function (entity) { return exports.selectQuery(exports.selectFilter(entity)); };
/**
 * @stable [29.02.2020]
 * @param {ISelectedWrapper<TEntity extends IEntity>} entity
 * @returns {TEntity}
 */
exports.selectSelectedEntity = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.selected;
};
/**
 * @stable [19.01.2020]
 * @param {IEffectsAction} action
 * @returns {TEntity}
 */
exports.selectSelectedEntityFromAction = function (action) { return cond_1.ifNotNilThanValue(select_1.selectData(action), function (data) { return data.selected; }, definitions_interface_1.UNDEF_SYMBOL); };
/**
 * @stable [19.01.2020]
 * @param {IEffectsAction} action
 * @returns {EntityIdT}
 */
exports.selectSelectedEntityIdFromAction = function (action) { return cond_1.ifNotNilThanValue(exports.selectSelectedEntityFromAction(action), function (entity) { return exports.selectEntityId(entity); }, definitions_interface_1.UNDEF_SYMBOL); };
/**
 * @stable [20.10.2019]
 * @param {IPreviousActionWrapperEntity} data
 * @returns {IEffectsAction}
 */
exports.selectPreviousAction = function (data) {
    return cond_1.ifNotNilThanValue(data, function () { return data.previousAction; }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [20.10.2019]
 * @param {IEffectsAction} action
 * @returns {IEffectsAction}
 */
exports.selectPreviousActionFromAction = function (action) { return cond_1.ifNotNilThanValue(action, function () { return nvl_1.coalesce(exports.selectPreviousAction(action.data), exports.selectPreviousAction(action.initialData), definitions_interface_1.UNDEF); }, definitions_interface_1.UNDEF_SYMBOL); };
/**
 * @stable [20.10.2019]
 * @param {IEffectsAction} action
 * @returns {string}
 */
exports.selectPreviousActionTypeFromAction = function (action) { return cond_1.ifNotNilThanValue(exports.selectPreviousActionFromAction(action), function (previousAction) { return previousAction.type; }, definitions_interface_1.UNDEF_SYMBOL); };
/**
 * @stable [20.10.2019]
 * @param {IPreventEffectsWrapper} data
 * @returns {boolean}
 */
exports.selectPreventEffects = function (data) {
    return cond_1.ifNotNilThanValue(data, function () { return data.preventEffects; }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [20.10.2019]
 * @param {IEffectsAction} action
 * @returns {boolean}
 */
exports.selectPreventEffectsFromAction = function (action) { return cond_1.ifNotNilThanValue(action, function () { return nvl_1.coalesce(exports.selectPreventEffects(action.data), exports.selectPreventEffects(action.initialData), definitions_interface_1.UNDEF); }, definitions_interface_1.UNDEF_SYMBOL); };
/**
 * @stable [20.02.2020]
 * @param {IInitialDataWrapper<TData>} wrapper
 * @returns {TData}
 */
exports.selectInitialData = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.initialData;
};
/**
 * @stable [28.01.2020]
 * @param {IPayloadWrapper<TPayload>} wrapper
 * @returns {TPayload}
 */
exports.selectPayload = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.payload; }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [28.01.2020]
 * @param {IEffectsAction} action
 * @returns {TPayload}
 */
exports.selectDataPayloadFromAction = function (action) {
    return exports.selectPayload(select_1.selectData(action));
};
/**
 * @stable [20.02.2020]
 * @param {IEffectsAction} action
 * @returns {TPayload}
 */
exports.selectInitialDataPayloadFromAction = function (action) {
    return exports.selectPayload(exports.selectInitialData(action));
};
/**
 * @stable [13.02.2020]
 * @param {IEffectsAction} action
 * @returns {TResult}
 */
exports.selectErrorFromAction = function (action) {
    return exports.selectError(action);
};
/**
 * @stable [19.10.2019]
 * @param {IRawDataWrapper<TData>} listEntity
 * @returns {TData}
 */
exports.selectListRawDataEntity = function (listEntity) {
    return cond_1.ifNotNilThanValue(listEntity, function () { return listEntity.rawData; }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [10.02.2020]
 * @param {ITabPanelWrapperEntity} entity
 * @returns {IGenericTabPanelEntity}
 */
exports.selectTabPanelEntity = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.tabPanel;
};
/**
 * @stable [18.10.2019]
 * @param {IListWrapperEntity} listWrapperEntity
 * @returns {TData}
 */
exports.selectListWrapperRawDataEntity = function (listWrapperEntity) {
    return exports.selectListRawDataEntity(exports.selectListEntity(listWrapperEntity));
};
/**
 * @stable [19.10.2019]
 * @param {IListWrapperEntity<TEntity extends IEntity>} listWrapperEntity
 * @returns {TEntity}
 */
exports.selectListSelectedEntity = function (listWrapperEntity) {
    return cond_1.ifNotNilThanValue(exports.selectListEntity(listWrapperEntity), function (list) { return exports.selectSelectedEntity(list); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [30.08.2019]
 * @param {IQueryFilterWrapperEntity} entity
 * @returns {string}
 */
exports.selectFilterWrapperQuery = function (entity) {
    return cond_1.ifNotNilThanValue(exports.selectFilter(entity), function (filterEntity) { return exports.selectQuery(filterEntity); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [20.10.2019]
 * @param {EntityIdT} id
 * @returns {IEntityIdTWrapper}
 */
exports.mapEntityId = function (id) {
    return filter_1.defValuesFilter({ id: id });
};
/**
 * @stable [28.01.2020]
 * @param {boolean} progress
 * @returns {IProgressWrapper}
 */
exports.mapProgress = function (progress) {
    return filter_1.defValuesFilter({ progress: progress });
};
/**
 * @stable [29.01.2020]
 * @param {boolean} waitingForOptions
 * @returns {IWaitingForOptionsWrapper}
 */
exports.mapWaitingForOptions = function (waitingForOptions) {
    return filter_1.defValuesFilter({ waitingForOptions: waitingForOptions });
};
/**
 * @stable [28.01.2020]
 * @param {TValue} options
 * @returns {IOptionsWrapper<TValue>}
 */
exports.mapOptions = function (options) {
    return filter_1.defValuesFilter({ options: options });
};
/**
 * @stable [13.11.2019]
 * @param {ISortDirectionsEntity} directions
 * @returns {ISortDirectionsWrapperEntity}
 */
exports.mapSortDirectionsWrapperEntity = function (directions) {
    return filter_1.defValuesFilter({ directions: directions });
};
/**
 * @stable [20.10.2019]
 * @param {IEntityIdTWrapper} entity
 * @returns {IEntityIdTWrapper}
 */
exports.mapIdentifiedEntity = function (entity) {
    return exports.mapEntityId(exports.selectEntityId(entity));
};
/**
 * @stable [10.02.2020]
 * @param {IGenericTabPanelEntity} tabPanel
 * @returns {ITabPanelWrapperEntity}
 */
exports.mapTabPanelEntity = function (tabPanel) {
    return filter_1.defValuesFilter({ tabPanel: tabPanel });
};
/**
 * @stable [21.11.2019]
 * @param {ITabPanelWrapperEntity} tabPanelWrapperEntity
 * @returns {ITabPanelWrapperEntity}
 */
exports.mapTabPanelWrapperEntity = function (tabPanelWrapperEntity) {
    return exports.mapTabPanelEntity(exports.selectTabPanelEntity(tabPanelWrapperEntity));
};
/**
 * @stable [28.09.2019]
 * @param {IUserEntity} user
 * @returns {IUserWrapperEntity}
 */
exports.mapUserEntity = function (user) {
    return filter_1.defValuesFilter({ user: user });
};
/**
 * @stable [12.10.2019]
 * @param {boolean} disabled
 * @returns {IDisabledWrapper}
 */
exports.mapDisabled = function (disabled) {
    return filter_1.defValuesFilter({ disabled: disabled });
};
/**
 * @stable [10.09.2019]
 * @param {string} query
 * @returns {IQueryWrapper}
 */
exports.mapQuery = function (query) { return filter_1.defValuesFilter({ query: query }); };
/**
 * @stable [29.02.2020]
 * @param {TEntity} filter
 * @returns {IFilterWrapper<TEntity>}
 */
exports.mapFilter = function (filter) {
    return filter_1.defValuesFilter({ filter: filter });
};
/**
 * @stable [29.02.2020]
 * @param {IQueryFilterEntity} filter
 * @returns {IQueryFilterWrapperEntity}
 */
exports.mapQueryFilterEntity = function (filter) { return exports.mapFilter(filter); };
/**
 * @stable [21.11.2019]
 * @param {IEditableEntity<TEntity extends IEntity>} form
 * @returns {IFormExtendedEditableEntity<TEntity extends IEntity>}
 */
exports.mapEditableEntity = function (form) {
    return filter_1.defValuesFilter({ form: form });
};
/**
 * @stable [04.09.2019]
 * @param {IListEntity} list
 * @returns {IListWrapperEntity}
 */
exports.mapListEntity = function (list) {
    return filter_1.defValuesFilter({ list: list });
};
/**
 * @stable [10.09.2019]
 * @param {IPagedEntity} entity
 * @returns {IPagedEntity}
 */
exports.mapPagedEntity = function (entity) { return cond_1.ifNotNilThanValue(entity, function () { return filter_1.defValuesFilter({
    page: entity.page,
    pageSize: entity.pageSize,
}); }, definitions_interface_1.UNDEF_SYMBOL); };
/**
 * @stable [13.11.2019]
 * @param {ISortDirectionEntity} entity
 * @returns {ISortDirectionEntity}
 */
exports.mapSortDirectionEntity = function (entity) { return cond_1.ifNotNilThanValue(entity, function () { return filter_1.defValuesFilter({
    index: entity.index,
    direction: entity.direction,
}); }, definitions_interface_1.UNDEF_SYMBOL); };
/**
 * @stable [04.10.2019]
 * @param {IListEntity} entity
 * @param {number} pageSize
 * @returns {IPagedEntity}
 */
exports.mapListPagedEntity = function (entity, pageSize) {
    if (pageSize === void 0) { pageSize = definitions_interface_1.DEFAULT_PAGE_SIZE; }
    return cond_1.ifNotNilThanValue(entity, function () { return filter_1.defValuesFilter({
        page: entity.lockPage ? entity.page : definitions_interface_1.FIRST_PAGE,
        pageSize: pageSize,
    }); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [12.10.2019]
 * @param {IProgressWrapper} entity
 * @returns {IDisabledWrapper}
 */
exports.mapDisabledProgressWrapper = function (entity) {
    return exports.mapDisabled(wrapper_1.inProgress(entity));
};
/**
 * @stable [12.10.2019]
 * @param {IListWrapperEntity} listWrapperEntity
 * @returns {IDisabledWrapper}
 */
exports.mapDisabledProgressListWrapperEntity = function (listWrapperEntity) {
    return exports.mapDisabledProgressWrapper(exports.selectListEntity(listWrapperEntity));
};
/**
 * @stable [04.10.2019]
 * @param {IListWrapperEntity} entity
 * @param {number} pageSize
 * @returns {IPagedEntity}
 */
exports.mapListWrapperPagedEntity = function (entity, pageSize) {
    if (pageSize === void 0) { pageSize = definitions_interface_1.DEFAULT_PAGE_SIZE; }
    return exports.mapListPagedEntity(exports.selectListEntity(entity), pageSize);
};
/**
 * @stable [10.09.2019]
 * @param {IPaginatedEntity} entity
 * @returns {IPaginatedEntity}
 */
exports.mapPaginatedEntity = function (entity) { return cond_1.ifNotNilThanValue(entity, function () { return filter_1.defValuesFilter(__assign({}, exports.mapPagedEntity(entity), { totalCount: entity.totalCount })); }, definitions_interface_1.UNDEF_SYMBOL); };
/**
 * @stable [04.09.2019]
 * @param {IListWrapperEntity} listWrapper
 * @returns {IListWrapperEntity}
 */
exports.mapListWrapperEntity = function (listWrapper) {
    return exports.mapListEntity(exports.selectListEntity(listWrapper));
};
/**
 * @stable [28.09.2019]
 * @param {IUserWrapperEntity} userWrapper
 * @returns {IUserWrapperEntity}
 */
exports.mapUserWrapperEntity = function (userWrapper) {
    return exports.mapUserEntity(exports.selectUserEntity(userWrapper));
};
/**
 * @stable [21.12.2019]
 * @param {TEntity} entity
 * @param {IEditableEntity} editableEntity
 * @returns {IExtendedEntity<TEntity extends IEntity>}
 */
exports.mapExtendedEntity = function (entity, editableEntity) {
    var originalEntity;
    var newEntity = entity_1.isNewEntity(entity);
    var defaultChanges = exports.selectDefaultChanges(editableEntity);
    cond_1.ifNotNilThanValue(nvl_1.nvl(defaultChanges, entity), function () { return (originalEntity = __assign({}, defaultChanges, entity)); });
    var changes = select_1.selectChanges(editableEntity) || {};
    return filter_1.defValuesFilter({
        changes: changes,
        entity: __assign({}, originalEntity, changes),
        entityId: cond_1.orUndef(!newEntity, function () { return entity.id; }),
        newEntity: newEntity,
        originalEntity: originalEntity,
    });
};
/**
 * @stable [25.12.2019]
 * @param {IEditableEntity<TEntity extends IEntity>} editableEntity
 * @returns {IExtendedEntity<TEntity extends IEntity>}
 */
exports.mapExtendedEditableEntity = function (editableEntity) {
    return exports.mapExtendedEntity(null, editableEntity);
};
/**
 * @stable [23.12.2019]
 * @param {IExtendedEntity<TEntity extends IEntity>} extendedEntity
 * @returns {IApiEntity<TEntity extends IEntity>}
 */
exports.mapApiEntity = function (extendedEntity) {
    var changes = extendedEntity.changes, entity = extendedEntity.entity, originalEntity = extendedEntity.originalEntity;
    var entityId = exports.selectEntityId(entity);
    var newEntity = R.isNil(entityId);
    return filter_1.defValuesFilter({
        changes: changes,
        diff: newEntity ? entity : changes,
        entity: entity,
        entityId: entityId,
        newEntity: newEntity,
        originalEntity: originalEntity,
    });
};
/**
 * @stable [06.09.2019]
 * @param {IListWrapperEntity} listWrapper
 * @param {IEditableEntity} editableEntity
 * @returns {IExtendedEntity<TEntity extends IEntity>}
 */
exports.mapListSelectedExtendedEntity = function (listWrapper, editableEntity) {
    return exports.mapExtendedEntity(exports.selectListSelectedEntity(listWrapper), editableEntity);
};
/**
 * @stable [04.09.2019]
 * @param {IQueryFilterWrapperEntity} queryFilter
 * @returns {IQueryFilterWrapperEntity}
 */
exports.mapQueryFilterWrapperEntity = function (queryFilter) {
    return exports.mapQueryFilterEntity(exports.selectFilter(queryFilter));
};
/**
 * @stable [10.09.2019]
 * @param {IQueryFilterWrapperEntity} entity
 * @returns {IQueryWrapper}
 */
exports.mapFilterWrapperQuery = function (entity) {
    return exports.mapQuery(exports.selectFilterWrapperQuery(entity));
};
/**
 * @stable [17.09.2019]
 * @param {boolean} actionsDisabled
 * @returns {IActionsDisabledWrapper}
 */
exports.mapActionsDisabled = function (actionsDisabled) {
    return filter_1.defValuesFilter({ actionsDisabled: actionsDisabled });
};
/**
 * @stable [17.09.2019]
 * @param {IListEntity} list
 * @returns {IActionsDisabledWrapper}
 */
exports.mapListActionsDisabled = function (list) {
    return exports.mapActionsDisabled(wrapper_1.inProgress(list));
};
/**
 * @stable [17.09.2019]
 * @param {IListWrapperEntity} listWrapper
 * @returns {}
 */
exports.mapListWrapperActionsDisabled = function (listWrapper) {
    return exports.mapListActionsDisabled(exports.selectListEntity(listWrapper));
};
/**
 * @stable [11.10.2019]
 * @param {TEntity[] | TEntity} data
 * @returns {Array<ISelectOptionEntity<TEntity extends IOptionEntity>>}
 */
exports.mapSelectOptions = function (data) {
    return cond_1.ifNotNilThanValue(data, function (entities) { return ([].concat(entities)
        .map(function (entity) { return filter_1.defValuesFilter({
        value: exports.selectEntityId(entity),
        label: entity.name,
        disabled: entity.disabled,
        rawData: entity,
    }); })); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [18.09.2019]
 * @param {IEditableEntity} editableEntity
 * @returns {ToolbarToolsEnum[]}
 */
exports.selectEditableEntityToolbarToolsActiveFilter = function (editableEntity) {
    return cond_1.ifNotEmptyThanValue(select_1.selectChanges(editableEntity), function () { return [definition_1.ToolbarToolsEnum.FILTER]; }, []);
};
/**
 * @stable [18.09.2019]
 * @param {IFormExtendedEditableEntity} fEntity
 * @returns {ToolbarToolsEnum[]}
 */
exports.selectFormEntityToolbarToolsActiveFilter = function (fEntity) {
    return exports.selectEditableEntityToolbarToolsActiveFilter(exports.selectEditableEntity(fEntity));
};
/**
 * @stable [28.01.2020]
 * @param {IDictionaryEntity<TEntity>} dictionaryEntity
 * @param {(data: (TEntity[] | TEntity)) => AnyT} accessor
 * @returns {Array<ISelectOptionEntity<TEntity>>}
 */
exports.selectDictionaryEntityOptions = function (dictionaryEntity, accessor) {
    return exports.mapSelectOptions(cond_1.ifNotNilThanValue(select_1.selectData(dictionaryEntity), function (data) { return type_1.isFn(accessor) ? accessor(data) : data; }));
};
/**
 * @stable [28.01.2020]
 * @param {IDictionaryEntity<TDictionaryEntity>} dictionaryEntity
 * @returns {boolean}
 */
exports.selectDictionaryEntityLoading = function (dictionaryEntity) {
    return wrapper_1.isLoading(dictionaryEntity);
};
/**
 * @stable [28.01.2020]
 * @param {IDictionaryEntity<TEntity>} dictionaryEntity
 * @param {(data: TEntity[]) => TResult} accessor
 * @returns {IGenericBaseSelectEntity}
 */
exports.mapDictionaryEntityField = function (dictionaryEntity, accessor) {
    return (__assign({}, exports.mapWaitingForOptions(exports.selectDictionaryEntityLoading(dictionaryEntity)), exports.mapOptions(exports.selectDictionaryEntityOptions(dictionaryEntity, accessor))));
};
/**
 * @stable [25.11.2019]
 * @param {string[]} queue
 * @param {string | IOperationEntity} operations
 * @returns {boolean}
 */
exports.hasQueueOperations = function (queue) {
    var operations = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        operations[_i - 1] = arguments[_i];
    }
    return !R.isEmpty(R.intersection(queue, operations.map(function (operation) { return (type_1.isString(operation)
        ? operation
        : operation.id); })));
};
/**
 * @stable [25.11.2019]
 * @param {ITransportWrapperEntity} entity
 * @param {string | IOperationEntity} operations
 * @returns {boolean}
 */
exports.hasTransportWrapperQueueOperations = function (entity) {
    var operations = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        operations[_i - 1] = arguments[_i];
    }
    return exports.hasQueueOperations.apply(void 0, [exports.selectTransportWrapperQueue(entity)].concat(operations));
};
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
exports.isApplicationInProgress = function (entity) { return wrapper_1.inProgress(entity); };
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
exports.doesApplicationErrorExist = function (entity) { return wrapper_1.doesErrorExist(entity); };
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
exports.isApplicationMessageVisible = function (entity) {
    return exports.isApplicationInProgress(entity) || exports.doesApplicationErrorExist(entity) || !wrapper_1.isReady(entity);
};
/**
 * @stable [18.12.2019]
 * @param {IStackWrapperEntity} entity
 * @returns {IStackEntity}
 */
exports.selectStackEntity = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.stack; }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [18.12.2019]
 * @param {IStackEntity} entity
 * @returns {IStackItemEntity[]}
 */
exports.selectStackItemEntities = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function (data) { return data.stack; }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [18.12.2019]
 * @param {IStackWrapperEntity} entity
 * @returns {IStackItemEntity[]}
 */
exports.selectStackWrapperItemEntities = function (entity) {
    return exports.selectStackItemEntities(exports.selectStackEntity(entity));
};
//# sourceMappingURL=mapper.js.map