"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var cond_1 = require("./cond");
var type_1 = require("./type");
var calc_1 = require("./calc");
/**
 * @stable [03.02.2020]
 * @param {IValidWrapper} wrapper
 * @returns {boolean}
 */
exports.isValid = function (wrapper) { return R.isNil(wrapper) ? false : wrapper.valid !== false; };
/**
 * @stable [03.02.2020]
 * @param {IFieldRenderedWrapper} wrapper
 * @returns {boolean}
 */
exports.isFieldRendered = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.fieldRendered !== false;
};
/**
 * @stable [30.01.2020]
 * @param {IValidateOnMountWrapper} wrapper
 * @returns {boolean}
 */
exports.isValidateOnMount = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.validateOnMount !== false;
};
/**
 * @stable [03.02.2020]
 * @param {IPreventManualChangesWrapper} wrapper
 * @returns {boolean}
 */
exports.isPreventManualChanges = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.preventManualChanges !== true;
};
/**
 * @stable [30.01.2020]
 * @param {ICompactWrapper} wrapper
 * @returns {boolean}
 */
exports.isCompact = function (wrapper) { return R.isNil(wrapper) ? false : wrapper.compact === true; };
/**
 * @stable [30.01.2020]
 * @param {IPreventFocusWrapper} wrapper
 * @returns {boolean}
 */
exports.isFocusPrevented = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.preventFocus === true;
};
/**
 * @stable [03.02.2020]
 * @param {IProgressWrapper} wrapper
 * @returns {boolean}
 */
exports.inProgress = function (wrapper) { return R.isNil(wrapper) ? false : wrapper.progress === true; };
/**
 * @stable [15.01.2020]
 * @param {TEntity} wrapper
 * @returns {boolean}
 */
exports.isCheckModalNeeded = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.checkModal === true;
};
/**
 * @stable [11.03.2020]
 * @param {IConfirmWrapper} wrapper
 * @returns {boolean}
 */
exports.isConfirm = function (wrapper) { return R.isNil(wrapper) ? false : wrapper.confirm === true; };
/**
 * @stable [31.01.2020]
 * @param {IForceReloadWrapper} entity
 * @returns {boolean}
 */
exports.isForceReload = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.forceReload !== false; }, false);
};
/**
 * @stable [28.11.2019]
 * @param {IReadyWrapper} entity
 * @returns {boolean}
 */
exports.isReady = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.ready === true; }, false);
};
/**
 * @stable [24.01.2020]
 * @param {IFullWrapper} entity
 * @returns {boolean}
 */
exports.isFull = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.full !== false; }, false);
};
/**
 * @stable [02.02.2020]
 * @param {IIconWrapper<boolean | string>} entity
 * @returns {boolean}
 */
exports.hasIcon = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return !R.isNil(entity.icon) && entity.icon !== false; }, false);
};
/**
 * @stable [24.01.2020]
 * @param {IScrollableWrapper} entity
 * @returns {boolean}
 */
exports.isScrollable = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.scrollable !== false; }, false);
};
/**
 * @stable [24.01.2020]
 * @param {IDefaultWrapper} entity
 * @returns {boolean}
 */
exports.isDefault = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.default !== false; }, false);
};
/**
 * @stable [28.11.2019]
 * @param {IErrorWrapper} entity
 * @returns {boolean}
 */
exports.doesErrorExist = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () {
        return type_1.isBoolean(entity.error)
            ? entity.error === true
            : !R.isNil(entity.error);
    }, false);
};
/**
 * @stable [24.10.2019]
 * @param {IUseKeyboardWrapper} wrapper
 * @returns {boolean}
 */
exports.isKeyboardUsed = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.useKeyboard === true; }, false);
};
/**
 * @stable [25.10.2019]
 * @param {IVisibleWrapper} wrapper
 * @returns {boolean}
 */
exports.isVisible = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.visible !== false; }, false);
};
/**
 * @stable [30.01.2020]
 * @param {IActionsRenderedWrapper} wrapper
 * @returns {boolean}
 */
exports.isActionsRendered = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.actionsRendered !== false; }, false);
};
/**
 * @stable [30.10.2019]
 * @param {IFocusedWrapper} wrapper
 * @returns {boolean}
 */
exports.isFocused = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.focused === true; }, false);
};
/**
 * @stable [06.03.2020]
 * @param {IRangeEnabledWrapper} wrapper
 * @returns {boolean}
 */
exports.isRangeEnabled = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.rangeEnabled === true;
};
/**
 * @stable [26.10.2019]
 * @param {IHighlightOddWrapper} highlightOddEntity
 * @param {number} index
 * @returns {boolean}
 */
exports.isHighlightOdd = function (highlightOddEntity, index) {
    return cond_1.ifNotNilThanValue(highlightOddEntity, function () { return highlightOddEntity.highlightOdd !== false && (type_1.isNumber(index) ? calc_1.isOddNumber(index) : false); }, false);
};
/**
 * @stable [26.10.2019]
 * @param {IIndexedWrapper} indexedEntity
 * @returns {boolean}
 */
exports.isIndexed = function (indexedEntity) {
    return cond_1.ifNotNilThanValue(indexedEntity, function () { return indexedEntity.indexed === true; }, false);
};
/**
 * @stable [03.01.2019]
 * @param {IHeaderRenderedWrapper} headerRendered
 * @returns {boolean}
 */
exports.isHeaderRendered = function (headerRendered) {
    return cond_1.ifNotNilThanValue(headerRendered, function () { return headerRendered.headerRendered !== false; }, false);
};
/**
 * @stable [11.01.2020]
 * @param {IRenderedWrapper} value
 * @returns {boolean}
 */
exports.isRendered = function (value) {
    return cond_1.ifNotNilThanValue(value, function () { return value.rendered !== false; }, false);
};
/**
 * @stable [26.10.2019]
 * @param {IEditedWrapper} editedEntity
 * @returns {boolean}
 */
exports.isEdited = function (editedEntity) {
    return cond_1.ifNotNilThanValue(editedEntity, function () { return editedEntity.edited === true; }, false);
};
/**
 * @stable [26.10.2019]
 * @param {ISortableWrapper} wrapper
 * @returns {boolean}
 */
exports.isSortable = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.sortable === true; }, false);
};
/**
 * @stable [03.02.2020]
 * @param {IDisabledWrapper} wrapper
 * @returns {boolean}
 */
exports.isDisabled = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.disabled === true;
};
/**
 * @stable [03.02.2020]
 * @param {ISelectedWrapper} wrapper
 * @returns {boolean}
 */
exports.isSelected = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.selected === true;
};
/**
 * @stable [03.02.2020]
 * @param {ISelectableWrapper} wrapper
 * @returns {boolean}
 */
exports.isSelectable = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.selectable !== false;
};
/**
 * @stable [03.02.2020]
 * @param {IHoveredWrapper} wrapper
 * @returns {boolean}
 */
exports.isHovered = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.hovered !== false;
};
/**
 * @stable [03.02.2020]
 * @param {IExpandActionRenderedWrapper} wrapper
 * @returns {boolean}
 */
exports.isExpandActionRendered = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.expandActionRendered !== false;
};
/**
 * @stable [03.02.2020]
 * @param {ICalendarActionRenderedWrapper} wrapper
 * @returns {boolean}
 */
exports.isCalendarActionRendered = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.calendarActionRendered !== false;
};
/**
 * @stable [03.02.2020]
 * @param {IClearActionRenderedWrapper} wrapper
 * @returns {boolean}
 */
exports.isClearActionRendered = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.clearActionRendered !== false;
};
/**
 * @stable [03.02.2020]
 * @param {IReadOnlyWrapper} wrapper
 * @returns {boolean}
 */
exports.isReadOnly = function (wrapper) { return R.isNil(wrapper) ? false : wrapper.readOnly === true; };
/**
 * @stable [22.01.2020]
 * @param {IInlineWrapper} wrapper
 * @returns {boolean}
 */
exports.isInline = function (wrapper) { return R.isNil(wrapper) ? false : wrapper.inline === true; };
/**
 * @stable [28.10.2019]
 * @param {IChangeableWrapper} changeableWrapper
 * @returns {boolean}
 */
exports.isChangeable = function (changeableWrapper) {
    return cond_1.ifNotNilThanValue(changeableWrapper, function () { return changeableWrapper.changeable !== false; }, false);
};
/**
 * @stable [28.10.2019]
 * @param {IKeyboardOpenWrapper} wrapper
 * @returns {boolean}
 */
exports.isKeyboardOpen = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.keyboardOpen === true; }, false);
};
/**
 * @stable [29.10.2019]
 * @param {IRequiredWrapper} wrapper
 * @returns {boolean}
 */
exports.isRequired = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.required === true; }, false);
};
/**
 * @stable [30.10.2019]
 * @param {ISyntheticCursorWrapper} wrapper
 * @returns {boolean}
 */
exports.isSyntheticCursorUsed = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.syntheticCursor !== false; }, false);
};
/**
 * @stable [24.01.2020]
 * @param {IDecoratedWrapper} wrapper
 * @returns {boolean}
 */
exports.isDecorated = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.decorated !== false; }, false);
};
/**
 * @stable [13.11.2019]
 * @param {IMultiWrapper} wrapper
 * @returns {boolean}
 */
exports.isMulti = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.multi === true; }, false);
};
/**
 * @stable [23.11.2019]
 * @param {IRemoteFilterWrapper} wrapper
 * @returns {boolean}
 */
exports.isRemoteFilterApplied = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.remoteFilter === true; }, false);
};
/**
 * @stable [11.01.2020]
 * @param {IMenuRenderedWrapper} wrapper
 * @returns {boolean}
 */
exports.isMenuRendered = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.menuRendered === true; }, false);
};
/**
 * @stable [24.01.2020]
 * @param {IAnchoredWrapper} wrapper
 * @returns {boolean}
 */
exports.isAnchored = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.anchored === true; }, false);
};
/**
 * @stable [01.02.2020]
 * @param {IForceUseLocalFilterWrapper} wrapper
 * @returns {boolean}
 */
exports.isForceUseLocalFilter = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.forceUseLocalFilter === true; }, false);
};
/**
 * @stable [16.01.2020]
 * @param {ITouchedWrapper} wrapper
 * @returns {boolean}
 */
exports.isTouched = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.touched === true; }, false);
};
/**
 * @stable [23.11.2019]
 * @param {IUseFilterWrapper} wrapper
 * @returns {boolean}
 */
exports.isFilterUsed = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.useFilter === true; }, false);
};
/**
 * @stable [25.01.2020]
 * @param {IHeightRestrictedWrapper} wrapper
 * @returns {boolean}
 */
exports.isHeightRestricted = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.heightRestricted !== false; }, false);
};
/**
 * @stable [28.01.2020]
 * @param {IAllowEmptyFilterValueWrapper} wrapper
 * @returns {boolean}
 */
exports.isAllowEmptyFilterValue = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.allowEmptyFilterValue !== false; }, false);
};
/**
 * @stable [28.01.2020]
 * @param {ILoadingWrapper} entity
 * @returns {boolean}
 */
exports.isLoading = function (entity) {
    return R.isNil(entity) ? false : entity.loading === true;
};
/**
 * @stable [26.11.2019]
 * @param {IPlaceActionRenderedWrapper} entity
 * @returns {boolean}
 */
exports.isPlaceActionRendered = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.placeActionRendered !== false; }, false);
};
/**
 * @stable [11.01.2020]
 * @param {IUseZipCodeWrapper} entity
 * @returns {boolean}
 */
exports.isUseZipCode = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.useZipCode === true; }, false);
};
/**
 * @stable [14.01.2020]
 * @param {IPlainValueWrapper} entity
 * @returns {boolean}
 */
exports.isPlainValueApplied = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.plainValue !== false; }, false);
};
/**
 * @stable [10.02.2020]
 * @param {ISubHeaderRenderedWrapper} entity
 * @returns {boolean}
 */
exports.isSubHeaderRendered = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.subHeaderRendered !== false; }, false);
};
/**
 * @stable [19.12.2019]
 * @param {IRefreshOnUpdateWrapper} entity
 * @returns {boolean}
 */
exports.isRefreshOnUpdate = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.refreshOnUpdate === true; }, false);
};
/**
 * @stable [28.01.2020]
 * @param {IDisplayValueRenderedOnlyWrapper} entity
 * @returns {boolean}
 */
exports.isDisplayValueRenderedOnly = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.displayValueRenderedOnly === true; }, false);
};
/**
 * @stable [26.12.2019]
 * @param {IAlwaysDirtyWrapper} entity
 * @returns {boolean}
 */
exports.isAlwaysDirty = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.alwaysDirty === true; }, false);
};
/**
 * @stable [26.12.2019]
 * @param {IDirtyWrapper} entity
 * @returns {boolean}
 */
exports.isDirty = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.dirty === true; }, false);
};
/**
 * @stable [12.02.2020]
 * @param {IAllowSingleTabWrapper} entity
 * @returns {boolean}
 */
exports.isAllowSingleTab = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.allowSingleTab === true; }, false);
};
/**
 * @stable [12.02.2020]
 * @param {IWrappedWrapper} entity
 * @returns {boolean}
 */
exports.isWrapped = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.wrapped !== false; }, false);
};
/**
 * @stable [12.02.2020]
 * @param {IIconLeftAlignedWrapper} entity
 * @returns {boolean}
 */
exports.isIconLeftAligned = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.iconLeftAligned !== false; }, false);
};
/**
 * @stable [13.02.2020]
 * @param {TWrapper} entity
 * @returns {boolean}
 */
exports.isBackActionRendered = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.backActionRendered !== false; }, false);
};
/**
 * @stable [16.02.2020]
 * @param {IErrorMessageRenderedWrapper} wrapper
 * @returns {boolean}
 */
exports.isErrorMessageRendered = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.errorMessageRendered !== false;
};
//# sourceMappingURL=wrapper.js.map